Module: Henitai::CLI::Options

Includes:
RunOptions
Included in:
Henitai::CLI
Defined in:
lib/henitai/cli/options.rb

Overview

Builds the OptionParser instances for the run and clean commands and parses argv into an options Hash. Help/version options set @command_halted so the caller can skip the rest of the command. Run-only option definitions live in RunOptions.