Exception: Henitai::CoverageError
- Inherits:
-
StandardError
- Object
- StandardError
- Henitai::CoverageError
- Defined in:
- lib/henitai.rb
Overview
Raised when coverage data cannot be bootstrapped or validated.
Raised when coverage data cannot be bootstrapped or validated.